## $Id: export.py 16872 2022-03-09 20:53:31Z henrik $
##
## Copyright (C) 2012 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Exporters for applicant-related stuff.
"""
import grok
import sys
from waeup.kofa.applicants.interfaces import IApplicantBaseData
from waeup.kofa.utils.helpers import iface_names
from kofacustom.nigeria.applicants.export import NigeriaApplicantExporter
from kofacustom.nigeria.applicants.interfaces import INigeriaUGApplicant
from waeup.fceokene.applicants.interfaces import (
    ICustomUGApplicant, ITPURegistration)
from waeup.fceokene.applicants.schools_pandemic import SCHOOLS

class CustomApplicantExporter(NigeriaApplicantExporter):
    """Exporter for Nigeria Applicants.
    """

    fields = tuple(sorted(set(
        iface_names(ICustomUGApplicant) +
        iface_names(INigeriaUGApplicant) +
        iface_names(IApplicantBaseData) +
        iface_names(ITPURegistration)
        ))) + (
        'password', 'state', 'history', 'container_code', 'application_number',
        'display_fullname', 'application_date',
        'school_name1', 'school_name2', 'school_name3')

    def mangle_value(self, value, name, context=None):
        """The mangler determines the codes of the atributes `course1`,
        `course2` and `course_admitted`. It furthermore prepares the
        history messages and adds a hash symbol at the end of the phone number
        to avoid annoying automatic number transformation by Excel or Calc.
        """
        if name.startswith('school_name'):
            value = getattr(context, name.replace('_name', ''), None)
            if value:
                try:
                    value = '%s - %s - %s' % (
                        SCHOOLS[value][0], SCHOOLS[value][1], SCHOOLS[value][2])
                except:
                    pass
        if name == 'subj_comb' and value is not None:
            value = value.code
        return super(
            CustomApplicantExporter, self).mangle_value(
            value, name, context=context)